@@ -151,18 +151,18 @@ sub build_binaries {
   
   #possible targets:  im im_process im_jp2 im_fftw im_capture im_avi im_wmv
   #possible targets:  cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl cdcontextplus cdcairo
-  #possible targets:  iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio
+  #possible targets:  iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio iup_plot
   
   if ($self->notes('is_devel_cvs_version')) {
     ### DEVEL BUILD ###
     @imtargets  = qw[im im_process im_jp2 im_fftw im_capture];
     @cdtargets  = qw[cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio];
+    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupweb iuptuio iup_plot];
   }
   else {
     @imtargets  = qw[im];
     @cdtargets  = qw[cd_zlib cd_freetype cd];
-    @iuptargets = qw[iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib];
+    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iup_plot];
     #if ($^O eq 'openbsd') {
     #  warn "###WARN### skipping im_process on OpenBSD";
     #  @imtargets = grep { $_ !~ /^im_process$/ } @imtargets;
@@ -171,6 +171,7 @@ sub build_binaries {
     #  warn "###WARN### skipping iuptuio on Solaris";
     #  @iuptargets = grep { $_ !~ /^iuptuio$/ } @iuptargets;
     #}
+
     if ($^O eq 'solaris') {
       warn "###WARN### skipping iup_mglplot on Solaris (fails to compile)";
       @iuptargets = grep { $_ !~ /^iup_mglplot$/ } @iuptargets;
@@ -180,6 +181,7 @@ sub build_binaries {
   @cdtargets  = grep { $_ !~ /^(cd_ftgl|cdgl)$/ } @cdtargets unless $has{l_GLU};
   @iuptargets = grep { $_ !~ /^(iup_mglplot)$/ } @iuptargets unless $has{gl} && $has{glu};
   @iuptargets = grep { $_ !~ /^(iupgl)$/ } @iuptargets unless $has{glx};
+  @iuptargets = grep { $_ !~ /^(iupglcontrols)$/ } @iuptargets unless $has{glx};
   @iuptargets = grep { $_ !~ /^(iupweb)$/ } @iuptargets unless $has{webkit};
 
   #store debug info into ConfigData
@@ -219,7 +221,7 @@ sub build_binaries {
     my $msg = "\nYou have the following build options available:\n" .
               join("\n", map ($n++ . ") $_", @build_opts)) .
 	      "\nWhat do you wanna build?";
-    my $i = $self->prompt($msg, 1);
+    my $i = $ENV{TRAVIS} ? 1 : $self->prompt($msg, 1);
     $build_target = $build_opts[$i-1];
     die "###ERROR### Wrong selection!" unless $build_target;
   }
@@ -262,10 +264,13 @@ sub build_binaries {
 ### for X11/Motif you need: -lXm, -lX11 + Xm/Xm.h, X11/Xlib.h
 ### 
 ### on Debian/Ubuntu you need to install: 
-###  $ aptitude install libgtk2.0-dev libcairo2-dev libx11-dev libglu-dev
+###  $ aptitude install libgtk2.0-dev libcairo2-dev libx11-dev libglu-dev freeglut3-dev
 ### 
 ### on RedHat/CentOS/Fedora you need to install: 
-###  $ yum install gtk2-devel cairo-devel libX11-devel libGLU-devel
+###  $ yum install gtk2-devel cairo-devel libX11-devel libGLU-devel freeglut-devel
+###
+### on FreeBSD you need to install:
+###  $ pkg install gtk2 cairo freeglut
 ###
 MARKER
     die;
@@ -329,6 +334,11 @@ MARKER
   
   #extra options for iup/imglib
   push(@makeopts, 'USE_IUP_IMGLIB_LARGE=1') if $self->notes('build_large_imglib');
+  
+  if ($Config{cc} eq 'cc') {
+    # fix for: https://rt.cpan.org/Public/Bug/Display.html?id=94615
+    push(@makeopts, 'CC=cc', 'CPPC=c++');
+  }
 
   #do the job
   $success = $self->build_via_tecmake($build_out, $srcdir, \@makeopts, \@iuptargets, \@cdtargets, \@imtargets);
